@@ -32,6 +32,7 @@
 #include <string.h>
 #include <ctype.h>
 
+#include <glib/gi18n.h>
 #include <gnome.h>
 
 #include <gmenu-tree.h>
@@ -111,12 +112,7 @@ add_bugzilla_application (GHashTable *hash,
 			char *s;
 			s = strrchr (programv[0], G_DIR_SEPARATOR);
 			s = s ? s+1 : programv[0];
-			if (g_hash_table_lookup (hash, s) == NULL) {
-				g_hash_table_insert (hash, g_strdup (s), app);
-			} else {
-				g_free (app);
-				return;
-			}
+			g_hash_table_insert (hash, g_strdup (s), app);
 		} else {
 			g_free (app);
 			return;
@@ -128,28 +124,43 @@ add_bugzilla_application (GHashTable *hash,
 	if (other_programs) {
 		programv = g_strsplit (other_programs, ";", -1);
 		for (i=0; programv[i]; i++) {
-			if (g_hash_table_lookup (hash, programv[i]) == NULL) {
-				g_hash_table_insert (hash, g_strdup (programv[i]), app);
-			}
+			g_hash_table_insert (hash, g_strdup (programv[i]), app);
 		}
 		g_strfreev (programv);
 	}
 }
 
+static void
+application_free (BugzillaApplication *app)
+{
+	g_free (app->name);
+	g_free (app->cname);
+	g_free (app->comment);
+	g_free (app->icon);
+	g_free (app->bugzilla);
+	g_free (app->product);
+	g_free (app->component);
+	g_free (app->version);
+	g_free (app->extra_info_script);
+	g_free (app);
+}
+
+
+	
+
 static const GSList *
 get_i18n_slist (void)
 {
-  GList *langs_glist;
-  static GSList *langs_gslist;
+  const char * const *langs;
+  guint i;
+  static GSList *langs_gslist = NULL;
 
   if (langs_gslist)
 	  return langs_gslist;
 
-  langs_glist = (GList *)gnome_i18n_get_language_list ("LC_MESSAGES");
-  langs_gslist = NULL;
-  while (langs_glist != NULL) {
-    langs_gslist = g_slist_append (langs_gslist, langs_glist->data);
-    langs_glist = langs_glist->next;
+  langs = g_get_language_names ();
+  for (i = 0; langs[i] != 0; ++i) {
+	  langs_gslist = g_slist_append (langs_gslist, (gpointer) langs[i]);
   }
 
   return langs_gslist;
@@ -164,7 +175,6 @@ load_applets (GHashTable *hash)
 	GSList *langs;
 	int i;
         gchar *name;
-	GSList *l;
 
 	CORBA_exception_init (&ev);
 	info_list = bonobo_activation_query (APPLET_REQUIREMENTS, NULL, &ev);
@@ -334,10 +344,10 @@ load_applications (void)
 {
 	GSList         *all_applications;
 	GSList         *l;
-	const char     *prev_name = NULL;
+	char           *prev_name = NULL;
 	GError	       *error = NULL;
 
-	GHashTable *program_to_application = g_hash_table_new (g_str_hash, g_str_equal);
+	GHashTable *program_to_application = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) application_free);
 
 	all_applications = get_all_applications ();
 	for (l = all_applications; l; l = l->next) {
@@ -418,7 +428,8 @@ load_applications (void)
 		g_free (exec);
 		g_free (other_binaries);
 		g_free (extra_info_script);
-		prev_name = gmenu_tree_entry_get_name (entry);
+		g_free (prev_name);
+		prev_name = g_strdup (gmenu_tree_entry_get_name (entry));
 		g_key_file_free (key_file);	
 		gmenu_tree_item_unref (entry);
 	}
@@ -449,7 +460,7 @@ bugzilla_parse_response (SoupMessage *msg, GError **err)
 	long bugid;
 	int debug = 0;
 
-	g_return_if_fail (err == NULL || *err == NULL);
+	g_return_val_if_fail ((err == NULL || *err == NULL), -1);
 
 	if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
 		g_set_error (err, BUGZILLA_ERROR, BUGZILLA_ERROR_RECV_BAD_STATUS, 
@@ -535,9 +546,6 @@ bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gn
 		        GladeXML *xml, GError **err)
 {
 	SoupXmlrpcMessage *message;
-	char *debug_string;
-	char *distro;
-	char *comment;
 	char *user_agent;
 
 	g_return_val_if_fail (app != NULL, NULL);
